@@ -1,5 +1,5 @@
 /*
- * Copyright 1994-2016 Brad Lanam, Walnut Creek, CA
+ * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
  */
 
 /*
@@ -115,6 +115,15 @@ main (argc, argv)
 #endif
 
   disp = dimainproc (argc, argv, 0, &diData);
+  if (diData.options.exitFlag == DI_EXIT_FAIL) {
+    exit (2);
+  }
+  if (diData.options.exitFlag == DI_EXIT_WARN) {
+    exit (1);
+  }
+  if (diData.options.exitFlag == DI_EXIT_OK) {
+    exit (0);
+  }
   if (disp != (char *) NULL) {
     fputs (disp, stdout);
     free (disp);
