@@ -199,6 +199,7 @@ printDiskInfo (diData)
     Size_t              outcurrlen;
     char                *tout;
     int                 first;
+    int                 ishr;
 
 
     first = TRUE;
@@ -234,8 +235,10 @@ printDiskInfo (diData)
         --diout->width;
     }
 
-    if (diopts->dispBlockSize != (_print_size_t) DI_DISP_HR &&
-        diopts->dispBlockSize != (_print_size_t) DI_DISP_HR_2 &&
+    ishr = diopts->dispBlockSize == (_print_size_t) DI_DISP_HR ||
+      diopts->dispBlockSize == (_print_size_t) DI_DISP_HR_2;
+
+    if (! ishr &&
         (diopts->dispBlockSize > 0 &&
          diopts->dispBlockSize <= (_print_size_t) DI_VAL_1024)) {
       if (diopts->csv_output || diopts->json_output) {
@@ -249,7 +252,7 @@ printDiskInfo (diData)
       if (diopts->csv_output || diopts->json_output) {
         Snprintf1 (diout->blockFormatNR, sizeof (diout->blockFormatNR),
             "%%.0%s%%s", DI_Lf);
-        if (diopts->csv_tabs || diopts->json_output) {
+        if (! ishr) {
           Snprintf1 (diout->blockFormat, sizeof (diout->blockFormat),
               "%%.1%s%%s", DI_Lf);
         } else {
@@ -324,14 +327,10 @@ printDiskInfo (diData)
               inpool = FALSE;
             }
 
-            if (dinfo->doPrint)
-            {
+            if (dinfo->doPrint) {
               addTotals (dinfo, &totals, inpool);
-            }
-            else
-            {
-              if (debug > 2)
-              {
+            } else {
+              if (debug > 2) {
                 printf ("tot:%s:%s:skip\n", dinfo->special, dinfo->name);
               }
             }
@@ -861,9 +860,11 @@ printInfo (diskInfo, diopts, diout)
 
         default:
         {
-          ttext[0] = *ptr;
-          ttext[1] = '\0';
-          append (ttext, &out, &outcurrlen, &outlen);
+          if (! diopts->json_output) {
+            ttext[0] = *ptr;
+            ttext[1] = '\0';
+            append (ttext, &out, &outcurrlen, &outlen);
+          }
           break;
         }
       }
@@ -979,12 +980,62 @@ addTotals (diskInfo, totals, inpool)
         diskInfo->special, diskInfo->name, inpool);
   }
 
+  /*
+   * zfs:
+   *   The total is the space used + the space free.
+   *   Free space is the space available in the pool.
+   *   Available space is the space available in the pool.
+   *   Thus: total - free = used.
+   *   -- To get the real total, add the total for the pool
+   *      and all used space for all inpool filesystems.
+   *
+   * apfs:
+   *   An easy hierarchy:
+   *      /dev/disk1        the container, is not mounted.
+   *      /dev/disk1s1      partition 1
+   *      /dev/disk1s2      partition 2
+   *      /dev/disk1s3      partition 3
+   *   The first disk is used as the root of the pool, even though it
+   *     is not the container.
+   *   The total is the total space.
+   *   Free space is the space available + space used.
+   *      (or total space - space used).
+   *   Available space is the space available in the pool.
+   *   Thus: total - free = used.
+   *   -- To get (totals - free) to work for the totals, subtract
+   *      all free space returned by in-pool filesystems.
+   *
+   * hammer, hammer2:
+   *    Typically, a null mount is used such as:
+   *      /dev/serno/SERIAL.s1a   /build              hammer
+   *      /build/usr              /usr                null
+   *      /build/usr.local        /usr/local          null
+   *    There are also pfs mounts:
+   *      /dev/ad1s1a@LOCAL       /d1     hammer2
+   *      /dev/ad1s1a@d1.a        /d1/a   hammer2
+   *    Or
+   *      /dev/serno/SERIAL.s1a         /mnt        hammer2
+   *      /dev/serno/SERIAL.s1a@mnt.usr /mnt/usr    hammer2
+   *    Or
+   *      @build                  /build            hammer2
+   *      @build.var              /build/var        null
+   *  Difficult to process, as the naming is not consistent.
+   *  Not implemented.
+   *
+   * advfs:
+   *   Unknown.  Assume the same as zfs.
+   */
+
   if (inpool)
   {
-    if (debug > 2) {printf ("  tot:inpool:add total used\n"); }
-    /* if in a pool of disks, add the total used to the totals also */
-    totals->totalSpace += diskInfo->totalSpace - diskInfo->freeSpace;
-    totals->totalInodes += diskInfo->totalInodes - diskInfo->freeInodes;
+    if (debug > 2) {printf ("  tot:inpool:\n"); }
+    if (strcmp (diskInfo->fsType, "apfs") == 0) {
+      totals->freeSpace -= diskInfo->totalSpace - diskInfo->freeSpace;
+    } else {
+      /* zfs, old hammer, advfs */
+      totals->totalSpace += diskInfo->totalSpace - diskInfo->freeSpace;
+      totals->totalInodes += diskInfo->totalInodes - diskInfo->freeInodes;
+    }
   }
   else
   {
@@ -1235,9 +1286,11 @@ processTitles (diopts, diout)
 
           default:
           {
-            ttext[0] = *ptr;
-            ttext[1] = '\0';
-            append (ttext, &out, &outcurrlen, &outlen);
+            if (! diopts->json_output) {
+              ttext[0] = *ptr;
+              ttext[1] = '\0';
+              append (ttext, &out, &outcurrlen, &outlen);
+            }
             valid = FALSE;
             break;
           }
