@@ -19,8 +19,10 @@ rc=$?
 if [ $rc != 0 ]; then grc=$rc; fi
 if [ $grc -eq 0 ]; then
   ./getoptn_test.exe > ${_MKCONFIG_TSTRUNTMPDIR}/getoptn_test.out 2>&1
-  chkdiff ${_MKCONFIG_RUNTESTDIR}/getoptn.txt \
-      ${_MKCONFIG_TSTRUNTMPDIR}/getoptn_test.out
+  if [ -s ${_MKCONFIG_TSTRUNTMPDIR}/getoptn_test.out ]; then
+    chkdiff ${_MKCONFIG_RUNTESTDIR}/getoptn.txt \
+        ${_MKCONFIG_TSTRUNTMPDIR}/getoptn_test.out
+  fi
 fi
 
 exit $grc
