@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 #
@@ -245,9 +246,11 @@ fi
 
 _MKCONFIG_RUNTESTDIR=`pwd`
 export _MKCONFIG_RUNTESTDIR
+MKC_FILES=${MKC_FILES:-mkc_files}
+export MKC_FILES
 
 if [ $SUBDIR = F ]; then
-  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/_mkconfig_runtests
+  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/${MKC_FILES}/_mkconfig_runtests
   export _MKCONFIG_RUNTMPDIR
 
   CC=${CC:-cc}
@@ -256,9 +259,11 @@ if [ $SUBDIR = F ]; then
   export DC
 else
   btestdir=`echo $testdir | sed 's,.*/,,'`
-  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/_mkconfig_runtests/$btestdir
+  _MKCONFIG_RUNTMPDIR=$_MKCONFIG_RUNTOPDIR/${MKC_FILES}/_mkconfig_runtests/$btestdir
   export _MKCONFIG_RUNTMPDIR
 fi
+d=`dirname $_MKCONFIG_RUNTMPDIR`
+test -d $d || mkdir -p $d
 
 TMPORDER=test_order.tmp
 > $TMPORDER
@@ -290,20 +295,10 @@ if [ $SUBDIR = F ]; then
   getlistofshells
 fi
 
-locatecmd awkcmd awk
-locatecmd nawkcmd nawk
-locatecmd gawkcmd gawk
-locatecmd mawkcmd mawk
-if [ "$nawkcmd" != "" ]; then
-  awkcmd=$nawkcmd
-fi
-if [ "$mawkcmd" != "" ]; then
-  awkcmd=$mawkcmd
-fi
-if [ "$gawkcmd" != "" ]; then
-  awkcmd=$gawkcmd
-fi
+locateawkcmd
 echo "awk: $awkcmd" >&8
+locatepkgconfigcmd
+echo "pkg-config: $pkgconfigcmd" >&8
 
 export shelllist
 grc=0
@@ -333,7 +328,7 @@ while read tline; do
   if [ -d "$tbase" ]; then
     ocwd=`pwd`
     cd $_MKCONFIG_DIR
-    TMPOUT=${_MKCONFIG_TSTRUNTMPDIR}/${tbase}.out
+    TMPOUT=${_MKCONFIG_RUNTMPDIR}/${tbase}.out
     ${_MKCONFIG_SHELL} ./runtests.sh -s "$CC" "$DC" "$shelllist" "$_pthlist" $TMPOUT $testdir/$tbase
     retvals=`tail -1 $TMPOUT`
     rm -f $TMPOUT > /dev/null 2>&1
@@ -455,6 +450,10 @@ while read tline; do
   fi
   domath count "$count + 1"
 
+  if [ $src -eq 0 -a "$MKC_CLEAN_RUN_TMP" = Y ]; then
+    test -d "$_MKCONFIG_TSTRUNTMPDIR" && rm -rf "$_MKCONFIG_TSTRUNTMPDIR"
+  fi
+
   # for some reason, unixware can't handle this if it is split into
   # multiple lines.
   if [ "$DOPERL" = T -a \( $runshpl -eq $_MKC_PL -o $runshpl -eq $_MKC_SH_PL \) ]; then
@@ -503,6 +502,10 @@ while read tline; do
       echo " success" >&8
     fi
     domath count "$count + 1"
+
+    if [ $rc -eq 0 -a "$MKC_CLEAN_RUN_TMP" = Y ]; then
+      test -d "$_MKCONFIG_TSTRUNTMPDIR" && rm -rf "$_MKCONFIG_TSTRUNTMPDIR"
+    fi
   fi
 
   lastpass=$pass
@@ -521,7 +524,11 @@ if [ $SUBDIR = F ]; then
   echo "$count tests $fcount failures"
   if [ $fcount -eq 0 ]; then
     if [ "$MKC_KEEP_RUN_TMP" = "" ]; then
-      test -d "$_MKCONFIG_RUNTMPDIR" && rm -rf "$_MKCONFIG_RUNTMPDIR"
+      (
+        cd $_MKCONFIG_RUNTMPDIR/../..
+        test -d "$_MKCONFIG_RUNTMPDIR" && rm -rf "$_MKCONFIG_RUNTMPDIR"
+        test -d "${MKC_FILES}" && rmdir "${MKC_FILES}" > /dev/null 2>&1
+      )
     fi
   fi
 else
