@@ -1,6 +1,7 @@
 #!/bin/sh
 #
 # Copyright 2001-2018 Brad Lanam, Walnut Creek, California, USA
+# Copyright 2020 Brad Lanam Pleasant Hill CA
 #
 
 #
@@ -33,12 +34,12 @@ check_objext () {
   CC=${CC:-cc}
 
   > $TMPF.c puts '
-  #include <stdio.h>
-  main ()
-  {
-    printf ("hello\n");
-    return 0;
-  }
+#include <stdio.h>
+int main ()
+{
+  printf ("hello\n");
+  return 0;
+}
 '
 
   ${CC} -c $TMPF.c > /dev/null 2>&1 # don't care about warnings...
@@ -65,12 +66,12 @@ check_exeext () {
   CC=${CC:-cc}
 
   > $TMPF.c puts '
-  #include <stdio.h>
-  main ()
-  {
-    printf ("hello\n");
-    return 0;
-  }
+#include <stdio.h>
+int main ()
+{
+  printf ("hello\n");
+  return 0;
+}
 '
 
   ${CC} -o $TMPF $TMPF.c > /dev/null 2>&1 # don't care about warnings
