@@ -8,6 +8,9 @@ maindoquery $1 $_MKC_ONCE
 getsname $0
 dosetup $@
 
+. $_MKCONFIG_DIR/bin/shellfuncs.sh
+testshcapability
+
 unset DI_ARGS
 unset DIFMT
 FORMATS="b B u c f v i U F"
@@ -34,7 +37,7 @@ for d in C D; do
       # otherwise this test won't work.
       # include the normally excluded to get some data.
       # ctfs,objfs,sharefs have weird used inode counts (U)
-      didata=`${tdir}/di -n -d1 -f $format -t -a -x null,zfs,ctfs,objfs,sharefs 2>/dev/null `
+      didata=`${tdir}/di -n -d1 -f $format -t -a -x apfs,null,zfs,ctfs,objfs,sharefs 2>/dev/null `
       summtot=`(echo "0 ";echo $didata | sed 's/  */ + /g'; echo " - p") | dc`
       if [ $summtot -ne 0 ]; then
         putsnonl "*" >&5
